Upcoming Changes
@@@@@@@@@@@@@@@@@@@@@@@@@@@@

This page highlights changes expected for 0.5.0, which will likely be
released in late 2015. For a full list of issues targeted for that
version, see `milestone 0.5.0
<https://bitbucket.org/biocommons/hgvs/issues?milestone=0.5.0>`_.



Special Attention
$$$$$$$$$$$$$$$$$

*Check back later for updates*


Anticipated Features
$$$$$$$$$$$$$$$$$$$$

* :issue:`236`: Provide single-source sequence slices via a sister project, SeqDB
* :issue:`201`: Finish data provider REST Interface (implemented; needs merging)
* :issue:`104`: Support complex variants (implemented; needs merging)
